@@ -28,32 +28,24 @@ use super::options::ClientOptions;
 use super::request::*;
 use super::request_spec::*;
 use super::response::*;
+use super::{Header, HttpError, Verbosity};
+use crate::cli::Logger;
+use crate::http::ContextDir;
 use std::str::FromStr;
 use url::Url;
 
-#[derive(Clone, Debug, PartialEq, Eq)]
-pub enum HttpError {
-    StatuslineIsMissing,
-    CouldNotParseResponse,
-    TooManyRedirect,
-    Libcurl { code: i32, description: String },
-}
-
 #[derive(Debug)]
 pub struct Client {
-    pub options: ClientOptions,
     pub handle: Box<easy::Easy>,
     pub redirect_count: usize,
-    // unfortunately, follow-location feature from libcurl can not be used
+    // Unfortunately, follow-location feature from libcurl can not be used
     // libcurl returns a single list of headers for the 2 responses
-    // hurl needs to keep everything
+    // Hurl needs to keep everything.
 }
 
 impl Client {
-    ///
-    /// Init HTTP hurl client
-    ///
-    pub fn init(options: ClientOptions) -> Client {
+    /// Creates HTTP Hurl client.
+    pub fn new(cookie_input_file: Option<String>) -> Client {
         let mut h = easy::Easy::new();
 
         // Set handle attributes
@@ -61,37 +53,44 @@ impl Client {
 
         // Activate cookie storage
         // with or without persistence (empty string)
-        h.cookie_file(
-            options
-                .cookie_input_file
-                .clone()
-                .unwrap_or_else(|| "".to_string())
-                .as_str(),
-        )
-        .unwrap();
+        h.cookie_file(cookie_input_file.unwrap_or_else(|| "".to_string()).as_str())
+            .unwrap();
 
         Client {
-            options,
             handle: Box::new(h),
             redirect_count: 0,
         }
     }
 
+    /// Executes an HTTP request, optionally follows redirection and returns a
+    /// list of pair of [`Request`], [`Response`].
     ///
-    /// Execute an http request
+    /// # Arguments
     ///
+    /// * `request_spec` - A request specification
+    /// * `options`- Options for this execution
+    /// * `logger`- A logger
     pub fn execute_with_redirect(
         &mut self,
-        request: &RequestSpec,
+        request_spec: &RequestSpec,
+        options: &ClientOptions,
+        logger: &Logger,
     ) -> Result<Vec<(Request, Response)>, HttpError> {
         let mut calls = vec![];
 
-        let mut request_spec = request.clone();
+        let mut request_spec = request_spec.clone();
         self.redirect_count = 0;
         loop {
-            let (request, response) = self.execute(&request_spec)?;
+            let (request, response) = self.execute(&request_spec, options, logger)?;
             calls.push((request, response.clone()));
-            if let Some(url) = self.get_follow_location(response.clone()) {
+            if !options.follow_location {
+                break;
+            }
+
+            if let Some(url) = self.get_follow_location(&response) {
+                logger.debug("");
+                logger.debug(format!("=> Redirect to {}", url).as_str());
+                logger.debug("");
                 request_spec = RequestSpec {
                     method: Method::Get,
                     url,
@@ -105,7 +104,7 @@ impl Client {
                 };
 
                 self.redirect_count += 1;
-                if let Some(max_redirect) = self.options.max_redirect {
+                if let Some(max_redirect) = options.max_redirect {
                     if self.redirect_count > max_redirect {
                         return Err(HttpError::TooManyRedirect);
                     }
@@ -117,86 +116,135 @@ impl Client {
         Ok(calls)
     }
 
+    /// Executes an HTTP request, without following redirection and returns a
+    /// pair of [`Request`], [`Response`].
     ///
-    /// Execute an http request
+    /// # Arguments
     ///
-    pub fn execute(&mut self, request: &RequestSpec) -> Result<(Request, Response), HttpError> {
-        // set handle attributes
-        // that have not been set or reset
+    /// * `request_spec` - A request specification
+    /// * `options`- Options for this execution
+    /// * `logger`- A logger
+    pub fn execute(
+        &mut self,
+        request_spec: &RequestSpec,
+        options: &ClientOptions,
+        logger: &Logger,
+    ) -> Result<(Request, Response), HttpError> {
+        // Set handle attributes that have not been set or reset.
 
         // We force libcurl verbose mode regardless of Hurl verbose option to be able
         // to capture HTTP request headers in libcurl `debug_function`. That's the only
         // way to get access to the outgoing headers.
         self.handle.verbose(true).unwrap();
-        self.handle.ssl_verify_host(!self.options.insecure).unwrap();
-        self.handle.ssl_verify_peer(!self.options.insecure).unwrap();
-        if let Some(cacert_file) = self.options.cacert_file.clone() {
+        self.handle.ssl_verify_host(!options.insecure).unwrap();
+        self.handle.ssl_verify_peer(!options.insecure).unwrap();
+        if let Some(cacert_file) = options.cacert_file.clone() {
             self.handle.cainfo(cacert_file).unwrap();
             self.handle.ssl_cert_type("PEM").unwrap();
         }
 
-        if let Some(proxy) = self.options.proxy.clone() {
+        if let Some(proxy) = options.proxy.clone() {
             self.handle.proxy(proxy.as_str()).unwrap();
         }
-        if let Some(s) = self.options.no_proxy.clone() {
+        if let Some(s) = options.no_proxy.clone() {
             self.handle.noproxy(s.as_str()).unwrap();
         }
-        self.handle.timeout(self.options.timeout).unwrap();
+        self.handle.timeout(options.timeout).unwrap();
         self.handle
-            .connect_timeout(self.options.connect_timeout)
+            .connect_timeout(options.connect_timeout)
             .unwrap();
 
-        let url = self.generate_url(&request.url, &request.querystring);
+        let url = self.generate_url(&request_spec.url, &request_spec.querystring);
         self.handle.url(url.as_str()).unwrap();
-        self.set_method(&request.method);
-
-        self.set_cookies(&request.cookies);
-        self.set_form(&request.form);
-        self.set_multipart(&request.multipart);
-
-        let bytes = request.body.bytes();
-        let mut data: &[u8] = bytes.as_ref();
-        self.set_body(data);
-
-        self.set_headers(request);
-
-        let verbose = self.options.verbose;
-        let mut request_headers: Vec<Header> = vec![];
+        let method = &request_spec.method;
+        self.set_method(method);
+        self.set_cookies(&request_spec.cookies);
+        self.set_form(&request_spec.form);
+        self.set_multipart(&request_spec.multipart);
+        let mut request_spec_body: &[u8] = &request_spec.body.bytes();
+        self.set_body(request_spec_body);
+        self.set_headers(request_spec, options);
 
         let start = Instant::now();
+        let verbose = options.verbosity != None;
+        let very_verbose = options.verbosity == Some(Verbosity::VeryVerbose);
+        let mut request_headers: Vec<Header> = vec![];
         let mut status_lines = vec![];
-        let mut headers = vec![];
-        let mut body = Vec::<u8>::new();
+        let mut response_headers = vec![];
+        let has_body_data = !request_spec_body.is_empty()
+            || !request_spec.form.is_empty()
+            || !request_spec.multipart.is_empty();
+
+        // `request_body` are request body bytes computed by libcurl (the real bytes sent over the wire)
+        // whereas`request_spec_body` are request body bytes provided by Hurl user. For instance, if user uses
+        // a [FormParam] section, `request_body` is empty whereas libcurl sent a url-form encoded list
+        // of key-value.
+        let mut request_body = Vec::<u8>::new();
+        let mut response_body = Vec::<u8>::new();
         {
             let mut transfer = self.handle.transfer();
-            if !data.is_empty() {
+            if !request_spec_body.is_empty() {
                 transfer
-                    .read_function(|buf| Ok(data.read(buf).unwrap_or(0)))
+                    .read_function(|buf| Ok(request_spec_body.read(buf).unwrap_or(0)))
                     .unwrap();
             }
             transfer
                 .debug_function(|info_type, data| match info_type {
-                    // return all request headers (not one by one)
+                    // Return all request headers (not one by one)
                     easy::InfoType::HeaderOut => {
                         let mut lines = split_lines(data);
                         if verbose {
-                            for line in lines.clone() {
-                                eprintln!("> {}", line);
-                            }
+                            logger.method_version_out(&lines[0]);
                         }
 
-                        lines.pop().unwrap();
-                        lines.remove(0); //  method/url
+                        // Extracts request headers from libcurl debug info.
+                        lines.pop().unwrap(); // Remove last empty line.
+                        lines.remove(0); // Remove method/path/version line.
                         for line in lines {
-                            if let Some(header) = Header::parse(line) {
+                            if let Some(header) = Header::parse(&line) {
                                 request_headers.push(header);
                             }
                         }
+
+                        // If we don't send any data, we log headers and empty body here
+                        // instead of relying on libcurl computing body in easy::InfoType::DataOut.
+                        // because libcurl dont call easy::InfoType::DataOut if there is no data
+                        // to send.
+                        if !has_body_data && verbose {
+                            let debug_request = Request {
+                                url: url.to_string(),
+                                method: method.to_string(),
+                                headers: request_headers.clone(),
+                                body: Vec::new(),
+                            };
+                            for header in &debug_request.headers {
+                                logger.header_out(&header.name, &header.value);
+                            }
+                            logger.info(">");
+
+                            if very_verbose {
+                                debug_request.log_body(logger);
+                            }
+                        }
                     }
-                    easy::InfoType::HeaderIn => {
-                        if let Some(s) = decode_header(data) {
-                            if verbose {
-                                eprint!("< {}", s);
+                    // We use this callback to get the real body bytes sent by libcurl.
+                    easy::InfoType::DataOut => {
+                        // Extracts request body from libcurl debug info.
+                        request_body.extend(data);
+                        if verbose {
+                            let debug_request = Request {
+                                url: url.to_string(),
+                                method: method.to_string(),
+                                headers: request_headers.clone(),
+                                body: Vec::from(data),
+                            };
+                            for header in &debug_request.headers {
+                                logger.header_out(&header.name, &header.value);
+                            }
+                            logger.info(">");
+
+                            if very_verbose {
+                                debug_request.log_body(logger);
                             }
                         }
                     }
@@ -209,7 +257,7 @@ impl Client {
                         if s.starts_with("HTTP/") {
                             status_lines.push(s);
                         } else {
-                            headers.push(s)
+                            response_headers.push(s)
                         }
                     }
                     true
@@ -218,7 +266,7 @@ impl Client {
 
             transfer
                 .write_function(|data| {
-                    body.extend(data);
+                    response_body.extend(data);
                     Ok(data.len())
                 })
                 .unwrap();
@@ -229,39 +277,71 @@ impl Client {
                     None => e.description().to_string(),
                     Some(s) => s.to_string(),
                 };
-                return Err(HttpError::Libcurl { code, description });
+                return Err(HttpError::Libcurl {
+                    code,
+                    description,
+                    url: url.to_string(),
+                });
             }
         }
 
         let status = self.handle.response_code().unwrap();
+        // TODO: explain why status_lines is Vec ?
         let version = match status_lines.last() {
-            None => return Err(HttpError::StatuslineIsMissing {}),
-            Some(status_line) => self.parse_response_version(status_line.clone())?,
+            None => return Err(HttpError::StatuslineIsMissing { url }),
+            Some(status_line) => self.parse_response_version(status_line)?,
         };
-        let headers = self.parse_response_headers(&headers);
+        let headers = self.parse_response_headers(&response_headers);
         let duration = start.elapsed();
+        let lenght = response_body.len();
         self.handle.reset();
 
         let request = Request {
             url,
-            method: (&request.method).to_string(),
+            method: method.to_string(),
             headers: request_headers,
+            body: request_body,
         };
         let response = Response {
             version,
             status,
             headers,
-            body,
+            body: response_body,
             duration,
         };
+
+        if verbose {
+            logger.debug_important(
+                format!(
+                    "Response: (received {} bytes in {} ms)",
+                    lenght,
+                    duration.as_millis()
+                )
+                .as_str(),
+            );
+            logger.debug("");
+
+            // FIXME: Explain why there may be multiple status line
+            status_lines
+                .iter()
+                .filter(|s| s.starts_with("HTTP/"))
+                .for_each(|s| logger.status_version_in(s.trim()));
+
+            for header in &response.headers {
+                logger.header_in(&header.name, &header.value);
+            }
+            logger.info("<");
+            if very_verbose {
+                response.log_body(logger);
+            }
+        }
+
         Ok((request, response))
     }
 
-    ///
-    /// generate url
-    ///
+    /// Generates URL.
     fn generate_url(&mut self, url: &str, params: &[Param]) -> String {
-        let url = if params.is_empty() {
+        if params.is_empty() {
             url.to_string()
         } else {
             let url = if url.ends_with('?') {
@@ -271,15 +351,12 @@ impl Client {
             } else {
                 format!("{}?", url)
             };
-            let s = self.encode_params(params);
+            let s = self.url_encode_params(params);
             format!("{}{}", url, s)
-        };
-        url
+        }
     }
 
-    ///
-    /// set method
-    ///
+    /// Sets HTTP method.
     fn set_method(&mut self, method: &Method) {
         match method {
             Method::Get => self.handle.custom_request("GET").unwrap(),
@@ -294,10 +371,8 @@ impl Client {
         }
     }
 
-    ///
-    /// set request headers
-    ///
-    fn set_headers(&mut self, request: &RequestSpec) {
+    /// Sets HTTP headers.
+    fn set_headers(&mut self, request: &RequestSpec, options: &ClientOptions) {
         let mut list = easy::List::new();
 
         for header in &request.headers {
@@ -305,7 +380,7 @@ impl Client {
                 .unwrap();
         }
 
-        if get_header_values(&request.headers, "Content-Type").is_empty() {
+        if request.get_header_values("Content-Type").is_empty() {
             if let Some(ref s) = request.content_type {
                 list.append(format!("Content-Type: {}", s).as_str())
                     .unwrap();
@@ -314,12 +389,12 @@ impl Client {
             }
         }
 
-        if get_header_values(&request.headers, "Expect").is_empty() {
+        if request.get_header_values("Expect").is_empty() {
             list.append("Expect:").unwrap(); // remove header Expect
         }
 
-        if get_header_values(&request.headers, "User-Agent").is_empty() {
-            let user_agent = match self.options.user_agent {
+        if request.get_header_values("User-Agent").is_empty() {
+            let user_agent = match options.user_agent {
                 Some(ref u) => u.clone(),
                 None => format!("hurl/{}", clap::crate_version!()),
             };
@@ -327,25 +402,21 @@ impl Client {
                 .unwrap();
         }
 
-        if let Some(ref user) = self.options.user {
+        if let Some(ref user) = options.user {
             let authorization = base64::encode(user.as_bytes());
-            if get_header_values(&request.headers, "Authorization").is_empty() {
+            if request.get_header_values("Authorization").is_empty() {
                 list.append(format!("Authorization: Basic {}", authorization).as_str())
                     .unwrap();
             }
         }
-        if self.options.compressed
-            && get_header_values(&request.headers, "Accept-Encoding").is_empty()
-        {
+        if options.compressed && request.get_header_values("Accept-Encoding").is_empty() {
             list.append("Accept-Encoding: gzip, deflate, br").unwrap();
         }
 
         self.handle.http_headers(list).unwrap();
     }
 
-    ///
-    /// set request cookies
-    ///
+    /// Sets request cookies.
     fn set_cookies(&mut self, cookies: &[RequestCookie]) {
         let s = cookies
             .iter()
@@ -357,20 +428,16 @@ impl Client {
         }
     }
 
-    ///
-    /// set form
-    ///
+    /// Sets form params.
     fn set_form(&mut self, params: &[Param]) {
         if !params.is_empty() {
-            let s = self.encode_params(params);
+            let s = self.url_encode_params(params);
             self.handle.post_fields_copy(s.as_str().as_bytes()).unwrap();
             //self.handle.write_function(sink);
         }
     }
 
-    ///
-    /// set form
-    ///
+    /// Sets multipart form datas.
     fn set_multipart(&mut self, params: &[MultipartParam]) {
         if !params.is_empty() {
             let mut form = easy::Form::new();
@@ -396,9 +463,7 @@ impl Client {
         }
     }
 
-    ///
-    /// set body
-    ///
+    /// Sets request body.
     fn set_body(&mut self, data: &[u8]) {
         if !data.is_empty() {
             self.handle.post(true).unwrap();
@@ -406,10 +471,8 @@ impl Client {
         }
     }
 
-    ///
-    /// encode parameters
-    ///
-    fn encode_params(&mut self, params: &[Param]) -> String {
+    /// URL encodes parameters.
+    fn url_encode_params(&mut self, params: &[Param]) -> String {
         params
             .iter()
             .map(|p| {
@@ -420,10 +483,8 @@ impl Client {
             .join("&")
     }
 
-    ///
-    /// parse response version
-    ///
-    fn parse_response_version(&mut self, line: String) -> Result<Version, HttpError> {
+    /// Parses HTTP response version.
+    fn parse_response_version(&mut self, line: &str) -> Result<Version, HttpError> {
         if line.starts_with("HTTP/1.0") {
             Ok(Version::Http10)
         } else if line.starts_with("HTTP/1.1") {
@@ -435,35 +496,29 @@ impl Client {
         }
     }
 
-    ///
-    /// parse headers from libcurl responses
-    ///
+    /// Parse headers from libcurl responses.
     fn parse_response_headers(&mut self, lines: &[String]) -> Vec<Header> {
         let mut headers: Vec<Header> = vec![];
         for line in lines {
-            if let Some(header) = Header::parse(line.to_string()) {
+            if let Some(header) = Header::parse(line) {
                 headers.push(header);
             }
         }
         headers
     }
 
+    /// Retrieves an optional location to follow
     ///
-    /// retrieve an optional location to follow
     /// You need:
     /// 1. the option follow_location set to true
     /// 2. a 3xx response code
     /// 3. a header Location
-    ///
-    fn get_follow_location(&mut self, response: Response) -> Option<String> {
-        if !self.options.follow_location {
-            return None;
-        }
+    fn get_follow_location(&mut self, response: &Response) -> Option<String> {
         let response_code = response.status;
         if !(300..400).contains(&response_code) {
             return None;
         }
-        let location = match get_header_values(&response.headers, "Location").get(0) {
+        let location = match response.get_header_values("Location").get(0) {
             None => return None,
             Some(value) => value.clone(),
         };
@@ -475,9 +530,7 @@ impl Client {
         }
     }
 
-    ///
-    /// get cookie storage
-    ///
+    /// Returns cookie storage.
     pub fn get_cookie_storage(&mut self) -> Vec<Cookie> {
         let list = self.handle.cookies().unwrap();
         let mut cookies = vec![];
@@ -492,11 +545,9 @@ impl Client {
         cookies
     }
 
-    ///
-    /// Add cookie to Cookiejar
-    ///
-    pub fn add_cookie(&mut self, cookie: Cookie) {
-        if self.options.verbose {
+    /// Adds a cookie to the cookie jar.
+    pub fn add_cookie(&mut self, cookie: &Cookie, options: &ClientOptions) {
+        if options.verbosity != None {
             eprintln!("* add to cookie store: {}", cookie);
         }
         self.handle
@@ -504,25 +555,25 @@ impl Client {
             .unwrap();
     }
 
-    ///
-    /// Clear cookie storage
-    ///
-    pub fn clear_cookie_storage(&mut self) {
-        if self.options.verbose {
+    /// Clears cookie storage.
+    pub fn clear_cookie_storage(&mut self, options: &ClientOptions) {
+        if options.verbosity != None {
             eprintln!("* clear cookie storage");
         }
         self.handle.cookie_list("ALL").unwrap();
     }
 
-    ///
-    /// return curl command-line for the http request run by the client
-    ///
-    pub fn curl_command_line(&mut self, http_request: &RequestSpec) -> String {
+    /// Returns curl command-line for the HTTP `request_spec` run by this client.
+    pub fn curl_command_line(
+        &mut self,
+        request_spec: &RequestSpec,
+        context_dir: &ContextDir,
+        options: &ClientOptions,
+    ) -> String {
         let mut arguments = vec!["curl".to_string()];
-        let context_dir = &self.options.context_dir;
-        arguments.append(&mut http_request.curl_args(context_dir));
+        arguments.append(&mut request_spec.curl_args(context_dir));
 
-        let cookies = all_cookies(self.get_cookie_storage(), http_request);
+        let cookies = all_cookies(&self.get_cookie_storage(), request_spec);
         if !cookies.is_empty() {
             arguments.push("--cookie".to_string());
             arguments.push(format!(
@@ -534,21 +585,19 @@ impl Client {
                     .join("; ")
             ));
         }
-        arguments.append(&mut self.options.curl_args());
+        arguments.append(&mut options.curl_args());
         arguments.join(" ")
     }
 }
 
-///
-/// return cookies from both cookies from the cookie storage and the request
-///
-pub fn all_cookies(cookie_storage: Vec<Cookie>, request: &RequestSpec) -> Vec<RequestCookie> {
-    let mut cookies = request.cookies.clone();
+/// Returns cookies from both cookies from the cookie storage and the request.
+pub fn all_cookies(cookie_storage: &[Cookie], request_spec: &RequestSpec) -> Vec<RequestCookie> {
+    let mut cookies = request_spec.cookies.clone();
     cookies.append(
         &mut cookie_storage
             .iter()
             .filter(|c| c.expires != "1") // cookie expired when libcurl set value to 1?
-            .filter(|c| match_cookie(c, request.url.as_str()))
+            .filter(|c| match_cookie(c, request_spec.url.as_str()))
             .map(|c| RequestCookie {
                 name: (*c).name.clone(),
                 value: c.value.clone(),
@@ -558,11 +607,9 @@ pub fn all_cookies(cookie_storage: Vec<Cookie>, request: &RequestSpec) -> Vec<Re
     cookies
 }
 
-///
-/// Match cookie for a given url
-///
+/// Matches cookie for a given URL.
 pub fn match_cookie(cookie: &Cookie, url: &str) -> bool {
-    // is it possible to do it with libcurl?
+    // FIXME: is it possible to do it with libcurl?
     let url = match Url::parse(url) {
         Ok(url) => url,
         Err(_) => return false,
@@ -580,11 +627,9 @@ pub fn match_cookie(cookie: &Cookie, url: &str) -> bool {
 }
 
 impl Header {
-    ///
-    /// Parse an http header line received from the server
-    /// It does not panic. Just return none if it can not be parsed
-    ///
-    pub fn parse(line: String) -> Option<Header> {
+    /// Parses an HTTP header line received from the server
+    /// It does not panic. Just returns `None` if it can not be parsed.
+    pub fn parse(line: &str) -> Option<Header> {
         match line.find(':') {
             Some(index) => {
                 let (name, value) = line.split_at(index);
@@ -598,9 +643,7 @@ impl Header {
     }
 }
 
-///
-/// Split an array of bytes into http lines (\r\n separator)
-///
+/// Splits an array of bytes into HTTP lines (\r\n separator).
 fn split_lines(data: &[u8]) -> Vec<String> {
     let mut lines = vec![];
     let mut start = 0;
@@ -619,16 +662,14 @@ fn split_lines(data: &[u8]) -> Vec<String> {
     lines
 }
 
-///
-/// Decode optionally header value as text with utf8 or iso-8859-1 encoding
-///
+/// Decodes optionally header value as text with UTF-8 or ISO-8859-1 encoding.
 pub fn decode_header(data: &[u8]) -> Option<String> {
     match str::from_utf8(data) {
         Ok(s) => Some(s.to_string()),
         Err(_) => match ISO_8859_1.decode(data, DecoderTrap::Strict) {
             Ok(s) => Some(s),
             Err(_) => {
-                println!("Error decoding header both utf8 and iso-8859-1 {:?}", data);
+                println!("Error decoding header both UTF-8 and ISO-8859-1 {:?}", data);
                 None
             }
         },
@@ -642,20 +683,20 @@ mod tests {
     #[test]
     fn test_parse_header() {
         assert_eq!(
-            Header::parse("Foo: Bar\r\n".to_string()).unwrap(),
+            Header::parse("Foo: Bar\r\n").unwrap(),
             Header {
                 name: "Foo".to_string(),
                 value: "Bar".to_string(),
             }
         );
         assert_eq!(
-            Header::parse("Location: http://localhost:8000/redirected\r\n".to_string()).unwrap(),
+            Header::parse("Location: http://localhost:8000/redirected\r\n").unwrap(),
             Header {
                 name: "Location".to_string(),
                 value: "http://localhost:8000/redirected".to_string(),
             }
         );
-        assert!(Header::parse("Foo".to_string()).is_none());
+        assert!(Header::parse("Foo").is_none());
     }
 
     #[test]
