@@ -15,7 +15,6 @@
  * limitations under the License.
  *
  */
-use std::path::PathBuf;
 use std::time::Duration;
 
 #[derive(Debug, Clone)]
@@ -26,14 +25,19 @@ pub struct ClientOptions {
     pub cookie_input_file: Option<String>,
     pub proxy: Option<String>,
     pub no_proxy: Option<String>,
-    pub verbose: bool,
+    pub verbosity: Option<Verbosity>,
     pub insecure: bool,
     pub timeout: Duration,
     pub connect_timeout: Duration,
     pub user: Option<String>,
     pub user_agent: Option<String>,
     pub compressed: bool,
-    pub context_dir: PathBuf,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub enum Verbosity {
+    Verbose,
+    VeryVerbose,
 }
 
 impl Default for ClientOptions {
@@ -45,14 +49,13 @@ impl Default for ClientOptions {
             cookie_input_file: None,
             proxy: None,
             no_proxy: None,
-            verbose: false,
+            verbosity: None,
             insecure: false,
             timeout: Duration::from_secs(300),
             connect_timeout: Duration::from_secs(300),
             user: None,
             user_agent: None,
             compressed: false,
-            context_dir: PathBuf::new(),
         }
     }
 }
@@ -130,14 +133,13 @@ mod tests {
                 cookie_input_file: Some("cookie_file".to_string()),
                 proxy: Some("localhost:3128".to_string()),
                 no_proxy: None,
-                verbose: true,
+                verbosity: None,
                 insecure: true,
                 timeout: Duration::from_secs(10),
                 connect_timeout: Duration::from_secs(20),
                 user: Some("user:password".to_string()),
                 user_agent: Some("my-useragent".to_string()),
                 compressed: true,
-                context_dir: PathBuf::new()
             }
             .curl_args(),
             [
