@@ -33,14 +33,14 @@ impl Testcase {
     ///
     /// create an XML Junit <testcase> from an Hurl result
     ///
-    pub fn from_hurl_result(hurl_result: &HurlResult, lines: &[String]) -> Testcase {
+    pub fn from_hurl_result(hurl_result: &HurlResult, content: &str) -> Testcase {
         let id = hurl_result.filename.clone();
         let time_in_ms = hurl_result.time_in_ms;
         let mut failures = vec![];
         let mut errors = vec![];
 
         for error in hurl_result.errors() {
-            let message = cli::error_string(lines, hurl_result.filename.clone(), &error);
+            let message = cli::error_string_no_color(&hurl_result.filename, content, &error);
             if error.assert {
                 failures.push(message);
             } else {
@@ -105,7 +105,6 @@ mod test {
 
     #[test]
     fn test_create_testcase_success() {
-        let lines = vec![];
         let hurl_result = HurlResult {
             filename: "test.hurl".to_string(),
             entries: vec![],
@@ -115,7 +114,8 @@ mod test {
         };
 
         let mut buffer = Vec::new();
-        Testcase::from_hurl_result(&hurl_result, &lines)
+        let content = "";
+        Testcase::from_hurl_result(&hurl_result, &content)
             .to_xml()
             .write(&mut buffer)
             .unwrap();
@@ -127,10 +127,9 @@ mod test {
 
     #[test]
     fn test_create_testcase_failure() {
-        let lines = vec![
-            "GET http://localhost:8000/not_found".to_string(),
-            "HTTP/1.0 200".to_string(),
-        ];
+        let content = r#"GET http://localhost:8000/not_found
+HTTP/1.0 200
+"#;
         let hurl_result = HurlResult {
             filename: "test.hurl".to_string(),
             entries: vec![EntryResult {
@@ -139,26 +138,27 @@ mod test {
                 captures: vec![],
                 asserts: vec![],
                 errors: vec![Error {
-                    source_info: SourceInfo::init(2, 10, 2, 13),
+                    source_info: SourceInfo::new(2, 10, 2, 13),
                     inner: RunnerError::AssertStatus {
                         actual: "404".to_string(),
                     },
                     assert: true,
                 }],
                 time_in_ms: 0,
+                compressed: false,
             }],
             time_in_ms: 230,
             success: true,
             cookies: vec![],
         };
         let mut buffer = Vec::new();
-        Testcase::from_hurl_result(&hurl_result, &lines)
+        Testcase::from_hurl_result(&hurl_result, &content)
             .to_xml()
             .write(&mut buffer)
             .unwrap();
         assert_eq!(
             std::str::from_utf8(&buffer).unwrap(),
-            r#"<?xml version="1.0" encoding="UTF-8"?><testcase id="test.hurl" time="0.230"><failure>Assert Status
+            r#"<?xml version="1.0" encoding="UTF-8"?><testcase id="test.hurl" time="0.230"><failure>Assert status code
   --> test.hurl:2:10
    |
  2 | HTTP/1.0 200
@@ -169,7 +169,7 @@ mod test {
 
     #[test]
     fn test_create_testcase_error() {
-        let lines = vec!["GET http://unknown".to_string()];
+        let content = "GET http://unknown";
         let hurl_result = HurlResult {
             filename: "test.hurl".to_string(),
             entries: vec![EntryResult {
@@ -178,7 +178,7 @@ mod test {
                 captures: vec![],
                 asserts: vec![],
                 errors: vec![Error {
-                    source_info: SourceInfo::init(1, 5, 1, 19),
+                    source_info: SourceInfo::new(1, 5, 1, 19),
                     inner: RunnerError::HttpConnection {
                         url: "http://unknown".to_string(),
                         message: "(6) Could not resolve host: unknown".to_string(),
@@ -186,19 +186,20 @@ mod test {
                     assert: false,
                 }],
                 time_in_ms: 0,
+                compressed: false,
             }],
             time_in_ms: 230,
             success: true,
             cookies: vec![],
         };
         let mut buffer = Vec::new();
-        Testcase::from_hurl_result(&hurl_result, &lines)
+        Testcase::from_hurl_result(&hurl_result, content)
             .to_xml()
             .write(&mut buffer)
             .unwrap();
         assert_eq!(
             std::str::from_utf8(&buffer).unwrap(),
-            r#"<?xml version="1.0" encoding="UTF-8"?><testcase id="test.hurl" time="0.230"><error>Http Connection
+            r#"<?xml version="1.0" encoding="UTF-8"?><testcase id="test.hurl" time="0.230"><error>HTTP connection
   --> test.hurl:1:5
    |
  1 | GET http://unknown
