@@ -47,44 +47,44 @@ pub struct Request {
 }
 
 impl Request {
-    pub fn querystring_params(self) -> Vec<KeyValue> {
-        for section in self.sections {
-            if let SectionValue::QueryParams(params) = section.value {
-                return params;
+    pub fn querystring_params(&self) -> Vec<KeyValue> {
+        for section in &self.sections {
+            if let SectionValue::QueryParams(params) = &section.value {
+                return params.clone();
             }
         }
-        return vec![];
+        vec![]
     }
-    pub fn form_params(self) -> Vec<KeyValue> {
-        for section in self.sections {
-            if let SectionValue::FormParams(params) = section.value {
-                return params;
+    pub fn form_params(&self) -> Vec<KeyValue> {
+        for section in &self.sections {
+            if let SectionValue::FormParams(params) = &section.value {
+                return params.clone();
             }
         }
-        return vec![];
+        vec![]
     }
-    pub fn multipart_form_data(self) -> Vec<MultipartParam> {
-        for section in self.sections {
-            if let SectionValue::MultipartFormData(params) = section.value {
-                return params;
+    pub fn multipart_form_data(&self) -> Vec<MultipartParam> {
+        for section in &self.sections {
+            if let SectionValue::MultipartFormData(params) = &section.value {
+                return params.clone();
             }
         }
-        return vec![];
+        vec![]
     }
 
-    pub fn cookies(self) -> Vec<Cookie> {
-        for section in self.sections {
-            if let SectionValue::Cookies(cookies) = section.value {
-                return cookies;
+    pub fn cookies(&self) -> Vec<Cookie> {
+        for section in &self.sections {
+            if let SectionValue::Cookies(cookies) = &section.value {
+                return cookies.clone();
             }
         }
-        return vec![];
+        vec![]
     }
 
-    pub fn basic_auth(self) -> Option<KeyValue> {
-        for section in self.sections {
-            if let SectionValue::BasicAuth(kv) = section.value {
-                return Some(kv);
+    pub fn basic_auth(&self) -> Option<KeyValue> {
+        for section in &self.sections {
+            if let SectionValue::BasicAuth(kv) = &section.value {
+                return Some(kv.clone());
             }
         }
         None
@@ -106,21 +106,24 @@ pub struct Response {
 }
 
 impl Response {
-    pub fn captures(self) -> Vec<Capture> {
-        for section in self.sections {
-            if let SectionValue::Captures(captures) = section.value {
-                return captures;
+    /// Returns the captures list of this spec response.
+    pub fn captures(&self) -> Vec<Capture> {
+        for section in self.sections.iter() {
+            if let SectionValue::Captures(captures) = &section.value {
+                return captures.clone();
             }
         }
-        return vec![];
+        vec![]
     }
-    pub fn asserts(self) -> Vec<Assert> {
-        for section in self.sections {
-            if let SectionValue::Asserts(asserts) = section.value {
-                return asserts;
+
+    /// Returns the asserts list of this spec response.
+    pub fn asserts(&self) -> Vec<Assert> {
+        for section in self.sections.iter() {
+            if let SectionValue::Asserts(asserts) = &section.value {
+                return asserts.clone();
             }
         }
-        return vec![];
+        vec![]
     }
 }
 
@@ -207,6 +210,7 @@ impl Section {
             SectionValue::Cookies(_) => "Cookies",
             SectionValue::Captures(_) => "Captures",
             SectionValue::MultipartFormData(_) => "MultipartFormData",
+            SectionValue::Options(_) => "Options",
         }
     }
 }
@@ -221,6 +225,7 @@ pub enum SectionValue {
     Cookies(Vec<Cookie>),
     Captures(Vec<Capture>),
     Asserts(Vec<Assert>),
+    Options(Vec<EntryOption>),
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
@@ -230,15 +235,10 @@ pub struct Cookie {
     pub name: EncodedString,
     pub space1: Whitespace,
     pub space2: Whitespace,
-    pub value: CookieValue,
+    pub value: Template,
     pub line_terminator0: LineTerminator,
 }
 
-#[derive(Clone, Debug, PartialEq, Eq)]
-pub struct CookieValue {
-    pub value: String,
-}
-
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct KeyValue {
     pub line_terminators: Vec<LineTerminator>,
@@ -327,7 +327,7 @@ pub enum QueryValue {
     },
     Regex {
         space0: Whitespace,
-        expr: Template,
+        value: RegexValue,
     },
     Variable {
         space0: Whitespace,
@@ -339,6 +339,12 @@ pub enum QueryValue {
     Md5 {},
 }
 
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub enum RegexValue {
+    Template(Template),
+    Regex(Regex),
+}
+
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct CookiePath {
     pub name: Template,
@@ -387,7 +393,10 @@ pub struct Subquery {
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum SubqueryValue {
-    Regex { space0: Whitespace, expr: Template },
+    Regex {
+        space0: Whitespace,
+        value: RegexValue,
+    },
     Count {},
 }
 
@@ -627,7 +636,7 @@ pub struct SourceInfo {
 }
 
 impl SourceInfo {
-    pub fn init(
+    pub fn new(
         start_line: usize,
         start_col: usize,
         end_line: usize,
@@ -658,3 +667,112 @@ pub struct Variable {
     pub name: String,
     pub source_info: SourceInfo,
 }
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub enum EntryOption {
+    CaCertificate(CaCertificateOption),
+    Compressed(CompressedOption),
+    Insecure(InsecureOption),
+    FollowLocation(FollowLocationOption),
+    MaxRedirect(MaxRedirectOption),
+    Variable(VariableOption),
+    Verbose(VerboseOption),
+    VeryVerbose(VeryVerboseOption),
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct CompressedOption {
+    pub line_terminators: Vec<LineTerminator>,
+    pub space0: Whitespace,
+    pub space1: Whitespace,
+    pub space2: Whitespace,
+    pub value: bool,
+    pub line_terminator0: LineTerminator,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct InsecureOption {
+    pub line_terminators: Vec<LineTerminator>,
+    pub space0: Whitespace,
+    pub space1: Whitespace,
+    pub space2: Whitespace,
+    pub value: bool,
+    pub line_terminator0: LineTerminator,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct CaCertificateOption {
+    pub line_terminators: Vec<LineTerminator>,
+    pub space0: Whitespace,
+    pub space1: Whitespace,
+    pub space2: Whitespace,
+    pub filename: Filename,
+    pub line_terminator0: LineTerminator,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct VerboseOption {
+    pub line_terminators: Vec<LineTerminator>,
+    pub space0: Whitespace,
+    pub space1: Whitespace,
+    pub space2: Whitespace,
+    pub value: bool,
+    pub line_terminator0: LineTerminator,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct VeryVerboseOption {
+    pub line_terminators: Vec<LineTerminator>,
+    pub space0: Whitespace,
+    pub space1: Whitespace,
+    pub space2: Whitespace,
+    pub value: bool,
+    pub line_terminator0: LineTerminator,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct FollowLocationOption {
+    pub line_terminators: Vec<LineTerminator>,
+    pub space0: Whitespace,
+    pub space1: Whitespace,
+    pub space2: Whitespace,
+    pub value: bool,
+    pub line_terminator0: LineTerminator,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct MaxRedirectOption {
+    pub line_terminators: Vec<LineTerminator>,
+    pub space0: Whitespace,
+    pub space1: Whitespace,
+    pub space2: Whitespace,
+    pub value: usize,
+    pub line_terminator0: LineTerminator,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct VariableOption {
+    pub line_terminators: Vec<LineTerminator>,
+    pub space0: Whitespace,
+    pub space1: Whitespace,
+    pub space2: Whitespace,
+    pub value: VariableDefinition,
+    pub line_terminator0: LineTerminator,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct VariableDefinition {
+    pub name: String,
+    pub space0: Whitespace,
+    pub space1: Whitespace,
+    pub value: VariableValue,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub enum VariableValue {
+    Null {},
+    Bool(bool),
+    Integer(i64),
+    Float(Float),
+    String(Template),
+}
