@@ -15,8 +15,6 @@
  * limitations under the License.
  *
  */
-//use hurlfmt::format::text::format_token;
-//use hurlfmt::format::token::Tokenizable;
 use crate::ast::*;
 
 pub trait Htmlable {
@@ -132,16 +130,16 @@ impl Htmlable for Response {
 
 impl Htmlable for Method {
     fn to_html(&self) -> String {
-        return format!("<span class=\"method\">{}</span>", self);
+        format!("<span class=\"method\">{}</span>", self)
     }
 }
 
 impl Htmlable for Version {
     fn to_html(&self) -> String {
-        return format!(
+        format!(
             "<span class=\"version\">HTTP/{}</span>",
             self.value.as_str()
-        );
+        )
     }
 }
 
@@ -204,6 +202,11 @@ impl Htmlable for SectionValue {
                     buffer.push_str(item.to_html().as_str())
                 }
             }
+            SectionValue::Options(items) => {
+                for item in items {
+                    buffer.push_str(item.to_html().as_str())
+                }
+            }
         }
         buffer
     }
@@ -226,6 +229,179 @@ impl Htmlable for KeyValue {
     }
 }
 
+impl Htmlable for EntryOption {
+    fn to_html(&self) -> String {
+        match self {
+            EntryOption::CaCertificate(option) => option.to_html(),
+            EntryOption::Compressed(option) => option.to_html(),
+            EntryOption::Insecure(option) => option.to_html(),
+            EntryOption::FollowLocation(option) => option.to_html(),
+            EntryOption::MaxRedirect(option) => option.to_html(),
+            EntryOption::Variable(option) => option.to_html(),
+            EntryOption::Verbose(option) => option.to_html(),
+            EntryOption::VeryVerbose(option) => option.to_html(),
+        }
+    }
+}
+
+impl Htmlable for CompressedOption {
+    fn to_html(&self) -> String {
+        let mut buffer = String::from("");
+        add_line_terminators(&mut buffer, self.line_terminators.clone());
+        buffer.push_str("<span class=\"line\">");
+        buffer.push_str(self.space0.to_html().as_str());
+        buffer.push_str("<span class=\"string\">compressed</span>");
+        buffer.push_str(self.space1.to_html().as_str());
+        buffer.push_str("<span>:</span>");
+        buffer.push_str(self.space2.to_html().as_str());
+        buffer.push_str(format!("<span class=\"boolean\">{}</span>", self.value).as_str());
+        buffer.push_str("</span>");
+        buffer.push_str(self.line_terminator0.to_html().as_str());
+        buffer
+    }
+}
+
+impl Htmlable for InsecureOption {
+    fn to_html(&self) -> String {
+        let mut buffer = String::from("");
+        add_line_terminators(&mut buffer, self.line_terminators.clone());
+        buffer.push_str("<span class=\"line\">");
+        buffer.push_str(self.space0.to_html().as_str());
+        buffer.push_str("<span class=\"string\">insecure</span>");
+        buffer.push_str(self.space1.to_html().as_str());
+        buffer.push_str("<span>:</span>");
+        buffer.push_str(self.space2.to_html().as_str());
+        buffer.push_str(format!("<span class=\"boolean\">{}</span>", self.value).as_str());
+        buffer.push_str("</span>");
+        buffer.push_str(self.line_terminator0.to_html().as_str());
+        buffer
+    }
+}
+
+impl Htmlable for CaCertificateOption {
+    fn to_html(&self) -> String {
+        let mut buffer = String::from("");
+        add_line_terminators(&mut buffer, self.line_terminators.clone());
+        buffer.push_str("<span class=\"line\">");
+        buffer.push_str(self.space0.to_html().as_str());
+        buffer.push_str("<span class=\"string\">cacert</span>");
+        buffer.push_str(self.space1.to_html().as_str());
+        buffer.push_str("<span>:</span>");
+        buffer.push_str(self.space2.to_html().as_str());
+        buffer.push_str(self.filename.to_html().as_str());
+        buffer.push_str("</span>");
+        buffer.push_str(self.line_terminator0.to_html().as_str());
+        buffer
+    }
+}
+
+impl Htmlable for FollowLocationOption {
+    fn to_html(&self) -> String {
+        let mut buffer = String::from("");
+        add_line_terminators(&mut buffer, self.line_terminators.clone());
+        buffer.push_str("<span class=\"line\">");
+        buffer.push_str(self.space0.to_html().as_str());
+        buffer.push_str("<span class=\"string\">location</span>");
+        buffer.push_str(self.space1.to_html().as_str());
+        buffer.push_str("<span>:</span>");
+        buffer.push_str(self.space2.to_html().as_str());
+        buffer.push_str(format!("<span class=\"boolean\">{}</span>", self.value).as_str());
+        buffer.push_str("</span>");
+        buffer.push_str(self.line_terminator0.to_html().as_str());
+        buffer
+    }
+}
+
+impl Htmlable for MaxRedirectOption {
+    fn to_html(&self) -> String {
+        let mut buffer = String::from("");
+        add_line_terminators(&mut buffer, self.line_terminators.clone());
+        buffer.push_str("<span class=\"line\">");
+        buffer.push_str(self.space0.to_html().as_str());
+        buffer.push_str("<span class=\"string\">max-redirs</span>");
+        buffer.push_str(self.space1.to_html().as_str());
+        buffer.push_str("<span>:</span>");
+        buffer.push_str(self.space2.to_html().as_str());
+        buffer.push_str(format!("<span class=\"number\">{}</span>", self.value).as_str());
+        buffer.push_str("</span>");
+        buffer.push_str(self.line_terminator0.to_html().as_str());
+        buffer
+    }
+}
+
+impl Htmlable for VariableOption {
+    fn to_html(&self) -> String {
+        let mut buffer = String::from("");
+        add_line_terminators(&mut buffer, self.line_terminators.clone());
+        buffer.push_str("<span class=\"line\">");
+        buffer.push_str(self.space0.to_html().as_str());
+        buffer.push_str("<span class=\"string\">variable</span>");
+        buffer.push_str(self.space1.to_html().as_str());
+        buffer.push_str("<span>:</span>");
+        buffer.push_str(self.space2.to_html().as_str());
+        buffer.push_str(self.value.to_html().as_str());
+        buffer.push_str("</span>");
+        buffer.push_str(self.line_terminator0.to_html().as_str());
+        buffer
+    }
+}
+impl Htmlable for VariableDefinition {
+    fn to_html(&self) -> String {
+        let mut buffer = String::from("");
+        buffer.push_str(self.name.as_str());
+        buffer.push_str(self.space1.to_html().as_str());
+        buffer.push_str("<span>=</span>");
+        buffer.push_str(self.value.to_html().as_str());
+        buffer
+    }
+}
+
+impl Htmlable for VariableValue {
+    fn to_html(&self) -> String {
+        match self {
+            VariableValue::Null { .. } => "<span class=\"null\">null</span>".to_string(),
+            VariableValue::Bool(v) => format!("<span class=\"boolean\">{}</span>", v),
+            VariableValue::Integer(v) => format!("<span class=\"number\">{}</span>", v),
+            VariableValue::Float(v) => format!("<span class=\"number\">{}</span>", v),
+            VariableValue::String(t) => t.to_html(),
+        }
+    }
+}
+
+impl Htmlable for VerboseOption {
+    fn to_html(&self) -> String {
+        let mut buffer = String::from("");
+        add_line_terminators(&mut buffer, self.line_terminators.clone());
+        buffer.push_str("<span class=\"line\">");
+        buffer.push_str(self.space0.to_html().as_str());
+        buffer.push_str("<span class=\"string\">verbose</span>");
+        buffer.push_str(self.space1.to_html().as_str());
+        buffer.push_str("<span>:</span>");
+        buffer.push_str(self.space2.to_html().as_str());
+        buffer.push_str(format!("<span class=\"boolean\">{}</span>", self.value).as_str());
+        buffer.push_str("</span>");
+        buffer.push_str(self.line_terminator0.to_html().as_str());
+        buffer
+    }
+}
+
+impl Htmlable for VeryVerboseOption {
+    fn to_html(&self) -> String {
+        let mut buffer = String::from("");
+        add_line_terminators(&mut buffer, self.line_terminators.clone());
+        buffer.push_str("<span class=\"line\">");
+        buffer.push_str(self.space0.to_html().as_str());
+        buffer.push_str("<span class=\"string\">very-verbose</span>");
+        buffer.push_str(self.space1.to_html().as_str());
+        buffer.push_str("<span>:</span>");
+        buffer.push_str(self.space2.to_html().as_str());
+        buffer.push_str(format!("<span class=\"boolean\">{}</span>", self.value).as_str());
+        buffer.push_str("</span>");
+        buffer.push_str(self.line_terminator0.to_html().as_str());
+        buffer
+    }
+}
+
 impl Htmlable for MultipartParam {
     fn to_html(&self) -> String {
         match self {
@@ -298,15 +474,6 @@ impl Htmlable for Cookie {
     }
 }
 
-impl Htmlable for CookieValue {
-    fn to_html(&self) -> String {
-        format!(
-            "<span class=\"cookie-value\">{}</span>",
-            self.value.as_str()
-        )
-    }
-}
-
 impl Htmlable for Capture {
     fn to_html(&self) -> String {
         let mut buffer = String::from("");
@@ -374,12 +541,10 @@ impl Htmlable for QueryValue {
                     format!("<span class=\"string\">\"{}\"</span>", expr.to_html()).as_str(),
                 );
             }
-            QueryValue::Regex { space0, expr } => {
+            QueryValue::Regex { space0, value } => {
                 buffer.push_str("<span class=\"query-type\">regex</span>");
                 buffer.push_str(space0.to_html().as_str());
-                buffer.push_str(
-                    format!("<span class=\"string\">\"{}\"</span>", expr.to_html()).as_str(),
-                );
+                buffer.push_str(value.to_html().as_str());
             }
             QueryValue::Variable { space0, name } => {
                 buffer.push_str("<span class=\"query-type\">variable</span>");
@@ -404,17 +569,28 @@ impl Htmlable for QueryValue {
         buffer
     }
 }
+impl Htmlable for RegexValue {
+    fn to_html(&self) -> String {
+        match self {
+            RegexValue::Template(template) => {
+                format!("<span class=\"string\">\"{}\"</span>", template.to_html())
+            }
+            RegexValue::Regex(regex) => regex.to_html(),
+        }
+    }
+}
 
 impl Htmlable for Subquery {
     fn to_html(&self) -> String {
         let mut buffer = String::from("");
         match self.value.clone() {
-            SubqueryValue::Regex { expr, space0 } => {
+            SubqueryValue::Regex { value, space0 } => {
                 buffer.push_str("<span class=\"subquery-type\">regex</span>");
                 buffer.push_str(space0.to_html().as_str());
-                buffer.push_str(
-                    format!("<span class=\"string\">\"{}\"</span>", expr.to_html()).as_str(),
-                );
+                // buffer.push_str(
+                //     format!("<span class=\"string\">\"{}\"</span>", value.to_html()).as_str(),
+                // );
+                buffer.push_str(value.to_html().as_str());
             }
             SubqueryValue::Count {} => {
                 buffer.push_str("<span class=\"subquery-type\">count</span>")
@@ -846,7 +1022,7 @@ fn add_line_terminators(buffer: &mut String, line_terminators: Vec<LineTerminato
 }
 
 fn encode_html(s: String) -> String {
-    s.replace(">", "&gt;").replace("<", "&lt;")
+    s.replace('>', "&gt;").replace('<', "&lt;")
 }
 
 fn multilines(s: String) -> String {
@@ -868,7 +1044,7 @@ mod tests {
         let raw_string = RawString {
             newline: Whitespace {
                 value: "".to_string(),
-                source_info: SourceInfo::init(0, 0, 0, 0),
+                source_info: SourceInfo::new(0, 0, 0, 0),
             },
             value: Template {
                 quotes: false,
@@ -876,7 +1052,7 @@ mod tests {
                     value: "".to_string(),
                     encoded: "unused".to_string(),
                 }],
-                source_info: SourceInfo::init(0, 0, 0, 0),
+                source_info: SourceInfo::new(0, 0, 0, 0),
             },
         };
         assert_eq!(
@@ -888,7 +1064,7 @@ mod tests {
         let raw_string = RawString {
             newline: Whitespace {
                 value: "".to_string(),
-                source_info: SourceInfo::init(0, 0, 0, 0),
+                source_info: SourceInfo::new(0, 0, 0, 0),
             },
             value: Template {
                 quotes: false,
@@ -896,7 +1072,7 @@ mod tests {
                     value: "hello".to_string(),
                     encoded: "unused".to_string(),
                 }],
-                source_info: SourceInfo::init(0, 0, 0, 0),
+                source_info: SourceInfo::new(0, 0, 0, 0),
             },
         };
         assert_eq!(
@@ -911,7 +1087,7 @@ mod tests {
         let raw_string = RawString {
             newline: Whitespace {
                 value: "\n".to_string(),
-                source_info: SourceInfo::init(0, 0, 0, 0),
+                source_info: SourceInfo::new(0, 0, 0, 0),
             },
             value: Template {
                 quotes: false,
@@ -919,7 +1095,7 @@ mod tests {
                     value: "line1\nline2\n".to_string(),
                     encoded: "unused".to_string(),
                 }],
-                source_info: SourceInfo::init(0, 0, 0, 0),
+                source_info: SourceInfo::new(0, 0, 0, 0),
             },
         };
         assert_eq!(
@@ -952,7 +1128,7 @@ mod tests {
                         value: "id".to_string(),
                         encoded: "id".to_string(),
                     }],
-                    source_info: SourceInfo::init(0, 0, 0, 0),
+                    source_info: SourceInfo::new(0, 0, 0, 0),
                 },
                 space1: "".to_string(),
                 space2: " ".to_string(),
@@ -974,7 +1150,7 @@ mod tests {
                 value: "\n".to_string(),
                 encoded: "\\n".to_string(),
             }],
-            source_info: SourceInfo::init(0, 0, 0, 0),
+            source_info: SourceInfo::new(0, 0, 0, 0),
         });
         assert_eq!(
             value.to_html(),
