@@ -115,6 +115,10 @@ impl PredicateValue {
     pub fn is_bytearray(&self) -> bool {
         matches!(self, PredicateValue::Hex(_)) | matches!(self, PredicateValue::Base64(_))
     }
+
+    pub fn is_expression(&self) -> bool {
+        matches!(self, PredicateValue::Expression(_))
+    }
 }
 
 fn equal_predicate(reader: &mut Reader) -> ParseResult<'static, PredicateFuncValue> {
@@ -156,18 +160,19 @@ fn greater_predicate(reader: &mut Reader) -> ParseResult<'static, PredicateFuncV
     };
     let start = reader.state.clone();
     let value = predicate_value(reader)?;
-    if !value.is_number() {
-        return Err(Error {
+    if value.is_number() || value.is_string() || value.is_expression() {
+        Ok(PredicateFuncValue::GreaterThan {
+            space0,
+            value,
+            operator,
+        })
+    } else {
+        Err(Error {
             pos: start.pos,
             recoverable: false,
             inner: ParseError::PredicateValue {},
-        });
+        })
     }
-    Ok(PredicateFuncValue::GreaterThan {
-        space0,
-        value,
-        operator,
-    })
 }
 
 fn greater_or_equal_predicate(reader: &mut Reader) -> ParseResult<'static, PredicateFuncValue> {
@@ -179,18 +184,19 @@ fn greater_or_equal_predicate(reader: &mut Reader) -> ParseResult<'static, Predi
     };
     let start = reader.state.clone();
     let value = predicate_value(reader)?;
-    if !value.is_number() {
-        return Err(Error {
+    if value.is_number() || value.is_string() || value.is_expression() {
+        Ok(PredicateFuncValue::GreaterThanOrEqual {
+            space0,
+            value,
+            operator,
+        })
+    } else {
+        Err(Error {
             pos: start.pos,
             recoverable: false,
             inner: ParseError::PredicateValue {},
-        });
+        })
     }
-    Ok(PredicateFuncValue::GreaterThanOrEqual {
-        space0,
-        value,
-        operator,
-    })
 }
 
 fn less_predicate(reader: &mut Reader) -> ParseResult<'static, PredicateFuncValue> {
@@ -202,18 +208,19 @@ fn less_predicate(reader: &mut Reader) -> ParseResult<'static, PredicateFuncValu
     };
     let start = reader.state.clone();
     let value = predicate_value(reader)?;
-    if !value.is_number() {
-        return Err(Error {
+    if value.is_number() || value.is_string() || value.is_expression() {
+        Ok(PredicateFuncValue::LessThan {
+            space0,
+            value,
+            operator,
+        })
+    } else {
+        Err(Error {
             pos: start.pos,
             recoverable: false,
             inner: ParseError::PredicateValue {},
-        });
+        })
     }
-    Ok(PredicateFuncValue::LessThan {
-        space0,
-        value,
-        operator,
-    })
 }
 
 fn less_or_equal_predicate(reader: &mut Reader) -> ParseResult<'static, PredicateFuncValue> {
@@ -225,18 +232,19 @@ fn less_or_equal_predicate(reader: &mut Reader) -> ParseResult<'static, Predicat
     };
     let start = reader.state.clone();
     let value = predicate_value(reader)?;
-    if !value.is_number() {
-        return Err(Error {
+    if value.is_number() || value.is_string() || value.is_expression() {
+        Ok(PredicateFuncValue::LessThanOrEqual {
+            space0,
+            value,
+            operator,
+        })
+    } else {
+        Err(Error {
             pos: start.pos,
             recoverable: false,
             inner: ParseError::PredicateValue {},
-        });
+        })
     }
-    Ok(PredicateFuncValue::LessThanOrEqual {
-        space0,
-        value,
-        operator,
-    })
 }
 
 fn count_equal_predicate(reader: &mut Reader) -> ParseResult<'static, PredicateFuncValue> {
@@ -366,7 +374,7 @@ mod tests {
                 false,
                 Whitespace {
                     value: String::from(""),
-                    source_info: SourceInfo::init(1, 1, 1, 1),
+                    source_info: SourceInfo::new(1, 1, 1, 1),
                 }
             )
         );
@@ -379,7 +387,7 @@ mod tests {
                 true,
                 Whitespace {
                     value: String::from(" "),
-                    source_info: SourceInfo::init(1, 4, 1, 5),
+                    source_info: SourceInfo::new(1, 4, 1, 5),
                 }
             )
         );
@@ -395,17 +403,17 @@ mod tests {
                 not: true,
                 space0: Whitespace {
                     value: String::from(" "),
-                    source_info: SourceInfo::init(1, 4, 1, 5),
+                    source_info: SourceInfo::new(1, 4, 1, 5),
                 },
                 predicate_func: PredicateFunc {
-                    source_info: SourceInfo::init(1, 5, 1, 16),
+                    source_info: SourceInfo::new(1, 5, 1, 16),
                     value: PredicateFuncValue::Equal {
                         space0: Whitespace {
                             value: String::from(" "),
-                            source_info: SourceInfo::init(1, 11, 1, 12),
+                            source_info: SourceInfo::new(1, 11, 1, 12),
                         },
                         value: PredicateValue::Bool(true),
-                        operator: false
+                        operator: false,
                     },
                 },
             }
@@ -445,10 +453,10 @@ mod tests {
                 value: PredicateValue::Bool(true),
                 space0: Whitespace {
                     value: String::from("  "),
-                    source_info: SourceInfo::init(1, 7, 1, 9),
+                    source_info: SourceInfo::new(1, 7, 1, 9),
                 },
 
-                operator: false
+                operator: false,
             }
         );
 
@@ -458,13 +466,13 @@ mod tests {
             PredicateFuncValue::Equal {
                 value: PredicateValue::Float(Float {
                     value: 1.1,
-                    encoded: "1.1".to_string()
+                    encoded: "1.1".to_string(),
                 }),
                 space0: Whitespace {
                     value: String::from(" "),
-                    source_info: SourceInfo::init(1, 7, 1, 8),
+                    source_info: SourceInfo::new(1, 7, 1, 8),
                 },
-                operator: false
+                operator: false,
             }
         );
 
@@ -475,9 +483,9 @@ mod tests {
                 value: PredicateValue::Integer(2),
                 space0: Whitespace {
                     value: String::from(" "),
-                    source_info: SourceInfo::init(1, 7, 1, 8),
+                    source_info: SourceInfo::new(1, 7, 1, 8),
                 },
-                operator: false
+                operator: false,
             },
         );
 
@@ -488,9 +496,9 @@ mod tests {
                 value: PredicateValue::Integer(2),
                 space0: Whitespace {
                     value: String::from(" "),
-                    source_info: SourceInfo::init(1, 3, 1, 4),
+                    source_info: SourceInfo::new(1, 3, 1, 4),
                 },
-                operator: true
+                operator: true,
             },
         );
 
@@ -504,13 +512,13 @@ mod tests {
                         value: "Bob".to_string(),
                         encoded: "Bob".to_string(),
                     }],
-                    source_info: SourceInfo::init(1, 8, 1, 13),
+                    source_info: SourceInfo::new(1, 8, 1, 13),
                 }),
                 space0: Whitespace {
                     value: String::from(" "),
-                    source_info: SourceInfo::init(1, 7, 1, 8),
+                    source_info: SourceInfo::new(1, 7, 1, 8),
                 },
-                operator: false
+                operator: false,
             }
         );
     }
@@ -524,22 +532,22 @@ mod tests {
                 value: PredicateValue::Expression(Expr {
                     space0: Whitespace {
                         value: String::from(""),
-                        source_info: SourceInfo::init(1, 10, 1, 10),
+                        source_info: SourceInfo::new(1, 10, 1, 10),
                     },
                     variable: Variable {
                         name: "count".to_string(),
-                        source_info: SourceInfo::init(1, 10, 1, 15),
+                        source_info: SourceInfo::new(1, 10, 1, 15),
                     },
                     space1: Whitespace {
                         value: String::from(""),
-                        source_info: SourceInfo::init(1, 15, 1, 15),
+                        source_info: SourceInfo::new(1, 15, 1, 15),
                     },
                 }),
                 space0: Whitespace {
                     value: String::from(" "),
-                    source_info: SourceInfo::init(1, 7, 1, 8),
+                    source_info: SourceInfo::new(1, 7, 1, 8),
                 },
-                operator: false
+                operator: false,
             }
         );
     }
@@ -553,7 +561,7 @@ mod tests {
                 value: PredicateValue::Integer(2),
                 space0: Whitespace {
                     value: String::from(" "),
-                    source_info: SourceInfo::init(1, 12, 1, 13),
+                    source_info: SourceInfo::new(1, 12, 1, 13),
                 },
             }
         );
