@@ -96,6 +96,7 @@ impl ToJson for Request {
 }
 
 impl ToJson for Response {
+    /// Transforms this response to a JSON object.
     fn to_json(&self) -> JValue {
         let mut attributes = vec![];
         if let Some(v) = get_json_version(self.version.value.clone()) {
@@ -105,20 +106,15 @@ impl ToJson for Response {
             attributes.push(("status".to_string(), JValue::Number(n.to_string())));
         }
         add_headers(&mut attributes, self.headers.clone());
-        if !self.clone().captures().is_empty() {
-            let captures = self
-                .clone()
-                .captures()
-                .iter()
-                .map(|c| c.to_json())
-                .collect();
+        if !self.captures().is_empty() {
+            let captures = self.captures().iter().map(|c| c.to_json()).collect();
             attributes.push(("captures".to_string(), JValue::List(captures)));
         }
-        if !self.clone().asserts().is_empty() {
-            let asserts = self.clone().asserts().iter().map(|a| a.to_json()).collect();
+        if !self.asserts().is_empty() {
+            let asserts = self.asserts().iter().map(|a| a.to_json()).collect();
             attributes.push(("asserts".to_string(), JValue::List(asserts)));
         }
-        if let Some(body) = self.body.clone() {
+        if let Some(body) = &self.body {
             attributes.push(("body".to_string(), body.to_json()));
         }
         JValue::Object(attributes)
@@ -243,10 +239,7 @@ impl ToJson for Cookie {
     fn to_json(&self) -> JValue {
         let attributes = vec![
             ("name".to_string(), JValue::String(self.name.value.clone())),
-            (
-                "value".to_string(),
-                JValue::String(self.value.value.clone()),
-            ),
+            ("value".to_string(), JValue::String(self.value.to_string())),
         ];
         JValue::Object(attributes)
     }
@@ -307,9 +300,9 @@ fn query_value_attributes(query_value: &QueryValue) -> Vec<(String, JValue)> {
             attributes.push(("type".to_string(), JValue::String("xpath".to_string())));
             attributes.push(("expr".to_string(), JValue::String(expr.to_string())));
         }
-        QueryValue::Regex { expr, .. } => {
+        QueryValue::Regex { value, .. } => {
             attributes.push(("type".to_string(), JValue::String("regex".to_string())));
-            attributes.push(("expr".to_string(), JValue::String(expr.to_string())));
+            attributes.push(("expr".to_string(), value.to_json()));
         }
         QueryValue::Variable { name, .. } => {
             attributes.push(("type".to_string(), JValue::String("variable".to_string())));
@@ -341,9 +334,9 @@ impl ToJson for SubqueryValue {
     fn to_json(&self) -> JValue {
         let mut attributes = vec![];
         match self {
-            SubqueryValue::Regex { expr, .. } => {
+            SubqueryValue::Regex { value, .. } => {
                 attributes.push(("type".to_string(), JValue::String("regex".to_string())));
-                attributes.push(("expr".to_string(), JValue::String(expr.to_string())));
+                attributes.push(("expr".to_string(), value.to_json()));
             }
             SubqueryValue::Count { .. } => {
                 attributes.push(("type".to_string(), JValue::String("count".to_string())));
@@ -353,6 +346,25 @@ impl ToJson for SubqueryValue {
     }
 }
 
+impl ToJson for RegexValue {
+    fn to_json(&self) -> JValue {
+        match self {
+            RegexValue::Template(template) => JValue::String(template.to_string()),
+            RegexValue::Regex(regex) => regex.to_json(),
+        }
+    }
+}
+
+impl ToJson for Regex {
+    fn to_json(&self) -> JValue {
+        let attributes = vec![
+            ("type".to_string(), JValue::String("regex".to_string())),
+            ("value".to_string(), JValue::String(self.to_string())),
+        ];
+        JValue::Object(attributes)
+    }
+}
+
 impl ToJson for Predicate {
     fn to_json(&self) -> JValue {
         let mut attributes = vec![];
@@ -511,7 +523,7 @@ pub mod tests {
     fn whitespace() -> Whitespace {
         Whitespace {
             value: "".to_string(),
-            source_info: SourceInfo::init(0, 0, 0, 0),
+            source_info: SourceInfo::new(0, 0, 0, 0),
         }
     }
 
@@ -537,7 +549,7 @@ pub mod tests {
                         value: "http://example.com".to_string(),
                         encoded: "not_used".to_string(),
                     }],
-                    source_info: SourceInfo::init(0, 0, 0, 0),
+                    source_info: SourceInfo::new(0, 0, 0, 0),
                 },
                 line_terminator0: line_terminator(),
                 headers: vec![KeyValue {
@@ -547,7 +559,7 @@ pub mod tests {
                         value: "Foo".to_string(),
                         encoded: "unused".to_string(),
                         quotes: false,
-                        source_info: SourceInfo::init(0, 0, 0, 0),
+                        source_info: SourceInfo::new(0, 0, 0, 0),
                     },
                     space1: whitespace(),
                     space2: whitespace(),
@@ -557,13 +569,13 @@ pub mod tests {
                             value: "Bar".to_string(),
                             encoded: "unused".to_string(),
                         }],
-                        source_info: SourceInfo::init(0, 0, 0, 0),
+                        source_info: SourceInfo::new(0, 0, 0, 0),
                     },
                     line_terminator0: line_terminator(),
                 }],
                 sections: vec![],
                 body: None,
-                source_info: SourceInfo::init(0, 0, 0, 0),
+                source_info: SourceInfo::new(0, 0, 0, 0),
             }
             .to_json(),
             JValue::Object(vec![
@@ -590,19 +602,19 @@ pub mod tests {
                 line_terminators: vec![],
                 version: Version {
                     value: VersionValue::Version11,
-                    source_info: SourceInfo::init(0, 0, 0, 0),
+                    source_info: SourceInfo::new(0, 0, 0, 0),
                 },
                 space0: whitespace(),
                 status: Status {
                     value: StatusValue::Specific(200),
-                    source_info: SourceInfo::init(0, 0, 0, 0),
+                    source_info: SourceInfo::new(0, 0, 0, 0),
                 },
                 space1: whitespace(),
                 line_terminator0: line_terminator(),
                 headers: vec![],
                 sections: vec![],
                 body: None,
-                source_info: SourceInfo::init(0, 0, 0, 0),
+                source_info: SourceInfo::new(0, 0, 0, 0),
             }
             .to_json(),
             JValue::Object(vec![
@@ -618,19 +630,19 @@ pub mod tests {
                 line_terminators: vec![],
                 version: Version {
                     value: VersionValue::VersionAny,
-                    source_info: SourceInfo::init(0, 0, 0, 0),
+                    source_info: SourceInfo::new(0, 0, 0, 0),
                 },
                 space0: whitespace(),
                 status: Status {
                     value: StatusValue::Any,
-                    source_info: SourceInfo::init(0, 0, 0, 0),
+                    source_info: SourceInfo::new(0, 0, 0, 0),
                 },
                 space1: whitespace(),
                 line_terminator0: line_terminator(),
                 headers: vec![],
                 sections: vec![],
                 body: None,
-                source_info: SourceInfo::init(0, 0, 0, 0),
+                source_info: SourceInfo::new(0, 0, 0, 0),
             }
             .to_json(),
             JValue::Object(vec![])
@@ -639,7 +651,7 @@ pub mod tests {
 
     fn header_query() -> Query {
         Query {
-            source_info: SourceInfo::init(0, 0, 0, 0),
+            source_info: SourceInfo::new(0, 0, 0, 0),
             value: QueryValue::Header {
                 space0: whitespace(),
                 name: Template {
@@ -648,7 +660,7 @@ pub mod tests {
                         value: "Content-Length".to_string(),
                         encoded: "10".to_string(),
                     }],
-                    source_info: SourceInfo::init(0, 0, 0, 0),
+                    source_info: SourceInfo::new(0, 0, 0, 0),
                 },
             },
             subquery: None,
@@ -663,7 +675,7 @@ pub mod tests {
                 value: "size".to_string(),
                 encoded: "unused".to_string(),
                 quotes: false,
-                source_info: SourceInfo::init(0, 0, 0, 0),
+                source_info: SourceInfo::new(0, 0, 0, 0),
             },
             space1: whitespace(),
             space2: whitespace(),
@@ -688,7 +700,7 @@ pub mod tests {
             not: false,
             space0: whitespace(),
             predicate_func: PredicateFunc {
-                source_info: SourceInfo::init(0, 0, 0, 0),
+                source_info: SourceInfo::new(0, 0, 0, 0),
                 value: PredicateFuncValue::Equal {
                     space0: whitespace(),
                     value: PredicateValue::Integer(value),
