@@ -85,7 +85,7 @@ impl Lintable<Request> for Request {
         let mut sections: Vec<Section> = self.sections.iter().map(|e| e.lint()).collect();
         sections.sort_by_key(|k| section_value_index(k.value.clone()));
 
-        let source_info = SourceInfo::init(0, 0, 0, 0);
+        let source_info = SourceInfo::new(0, 0, 0, 0);
         Request {
             line_terminators,
             space0,
@@ -135,7 +135,7 @@ impl Lintable<Response> for Response {
             headers,
             sections,
             body: b,
-            source_info: SourceInfo::init(0, 0, 0, 0),
+            source_info: SourceInfo::new(0, 0, 0, 0),
         }
     }
 }
@@ -153,7 +153,7 @@ impl Lintable<Section> for Section {
             space0: empty_whitespace(),
             value: self.value.lint(),
             line_terminator0: self.clone().line_terminator0,
-            source_info: SourceInfo::init(0, 0, 0, 0),
+            source_info: SourceInfo::new(0, 0, 0, 0),
         }
     }
 }
@@ -185,17 +185,23 @@ impl Lintable<SectionValue> for SectionValue {
             SectionValue::Cookies(cookies) => {
                 SectionValue::Cookies(cookies.iter().map(|e| e.lint()).collect())
             }
+            SectionValue::Options(options) => {
+                SectionValue::Options(options.iter().map(|e| e.lint()).collect())
+            }
         }
     }
 }
 
 fn section_value_index(section_value: SectionValue) -> u32 {
     match section_value {
-        SectionValue::QueryParams(_) => 0,
-        SectionValue::BasicAuth(_) => 1,
-        SectionValue::FormParams(_) => 2,
-        SectionValue::MultipartFormData(_) => 3,
-        SectionValue::Cookies(_) => 3,
+        // Request sections
+        SectionValue::Options(_) => 0,
+        SectionValue::QueryParams(_) => 1,
+        SectionValue::BasicAuth(_) => 2,
+        SectionValue::FormParams(_) => 3,
+        SectionValue::MultipartFormData(_) => 4,
+        SectionValue::Cookies(_) => 5,
+        // Response sections
         SectionValue::Captures(_) => 0,
         SectionValue::Asserts(_) => 1,
     }
@@ -246,7 +252,7 @@ impl Lintable<Query> for Query {
 
     fn lint(&self) -> Query {
         Query {
-            source_info: SourceInfo::init(0, 0, 0, 0),
+            source_info: SourceInfo::new(0, 0, 0, 0),
             value: self.value.lint(),
             subquery: self
                 .subquery
@@ -291,8 +297,8 @@ impl Lintable<QueryValue> for QueryValue {
                 expr: expr.clone(),
                 space0: one_whitespace(),
             },
-            QueryValue::Regex { expr, .. } => QueryValue::Regex {
-                expr: expr.clone(),
+            QueryValue::Regex { value, .. } => QueryValue::Regex {
+                value: value.lint(),
                 space0: one_whitespace(),
             },
             QueryValue::Variable { name, .. } => QueryValue::Variable {
@@ -314,12 +320,25 @@ impl Lintable<Subquery> for Subquery {
     }
 
     fn lint(&self) -> Subquery {
-        let source_info = SourceInfo::init(0, 0, 0, 0);
+        let source_info = SourceInfo::new(0, 0, 0, 0);
         let value = self.value.lint();
         Subquery { source_info, value }
     }
 }
 
+impl Lintable<RegexValue> for RegexValue {
+    fn errors(&self) -> Vec<Error> {
+        let errors = vec![];
+        errors
+    }
+
+    fn lint(&self) -> RegexValue {
+        match self {
+            RegexValue::Template(template) => RegexValue::Template(template.lint()),
+            RegexValue::Regex(regex) => RegexValue::Regex(regex.clone()),
+        }
+    }
+}
 impl Lintable<SubqueryValue> for SubqueryValue {
     fn errors(&self) -> Vec<Error> {
         let errors = vec![];
@@ -328,9 +347,9 @@ impl Lintable<SubqueryValue> for SubqueryValue {
 
     fn lint(&self) -> SubqueryValue {
         match self {
-            SubqueryValue::Regex { expr, .. } => SubqueryValue::Regex {
+            SubqueryValue::Regex { value, .. } => SubqueryValue::Regex {
                 space0: one_whitespace(),
-                expr: expr.clone(),
+                value: value.lint(),
             },
             SubqueryValue::Count {} => SubqueryValue::Count {},
         }
@@ -406,7 +425,7 @@ impl Lintable<PredicateFunc> for PredicateFunc {
 
     fn lint(&self) -> PredicateFunc {
         PredicateFunc {
-            source_info: SourceInfo::init(0, 0, 0, 0),
+            source_info: SourceInfo::new(0, 0, 0, 0),
             value: self.value.lint(),
         }
     }
@@ -512,6 +531,7 @@ impl Lintable<PredicateValue> for PredicateValue {
         }
     }
 }
+
 impl Lintable<RawString> for RawString {
     fn errors(&self) -> Vec<Error> {
         let errors = vec![];
@@ -620,7 +640,7 @@ impl Lintable<File> for File {
             space0: one_whitespace(),
             filename: Filename {
                 value: self.filename.clone().value,
-                source_info: SourceInfo::init(0, 0, 0, 0),
+                source_info: SourceInfo::new(0, 0, 0, 0),
             },
             space1: empty_whitespace(),
         }
@@ -702,14 +722,14 @@ impl Lintable<FileParam> for FileParam {
 fn empty_whitespace() -> Whitespace {
     Whitespace {
         value: "".to_string(),
-        source_info: SourceInfo::init(0, 0, 0, 0),
+        source_info: SourceInfo::new(0, 0, 0, 0),
     }
 }
 
 fn one_whitespace() -> Whitespace {
     Whitespace {
         value: " ".to_string(),
-        source_info: SourceInfo::init(0, 0, 0, 0),
+        source_info: SourceInfo::new(0, 0, 0, 0),
     }
 }
 
@@ -739,7 +759,7 @@ impl Lintable<LineTerminator> for LineTerminator {
             None => empty_whitespace(),
             Some(_) => Whitespace {
                 value: self.clone().space0.value,
-                source_info: SourceInfo::init(0, 0, 0, 0),
+                source_info: SourceInfo::new(0, 0, 0, 0),
             },
         };
         let comment = self.clone().comment.map(|comment| comment.lint());
@@ -749,7 +769,7 @@ impl Lintable<LineTerminator> for LineTerminator {
             } else {
                 "\n".to_string()
             },
-            source_info: SourceInfo::init(0, 0, 0, 0),
+            source_info: SourceInfo::new(0, 0, 0, 0),
         };
         LineTerminator {
             space0,
@@ -788,6 +808,17 @@ impl Lintable<Template> for Template {
     }
 }
 
+impl Lintable<EntryOption> for EntryOption {
+    fn errors(&self) -> Vec<Error> {
+        let errors = vec![];
+        errors
+    }
+
+    fn lint(&self) -> EntryOption {
+        self.clone()
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
